==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/moneyorder.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	moneyorder.lang.inc.php 2015-08-12
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_MONEYORDER_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_MONEYORDER_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_MONEYORDER_PAYTO_DESC' => 'An wen sollen Zahlungen erfolgen?',
	'MODULE_PAYMENT_MONEYORDER_PAYTO_ERROR' => 'Fehler: Bitte geben Sie einen Zahlungsempfänger an.',
	'MODULE_PAYMENT_MONEYORDER_PAYTO_TITLE' => 'Zahlbar an:',
	'MODULE_PAYMENT_MONEYORDER_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_MONEYORDER_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_MONEYORDER_STATUS_DESC' => 'Möchten Sie Zahlungen per Vorkasse/Überweisung akzeptieren?',
	'MODULE_PAYMENT_MONEYORDER_STATUS_TITLE' => 'Vorkasse (Überweisung) Modul aktivieren.',
	'MODULE_PAYMENT_MONEYORDER_TEXT_DESCRIPTION' => 'Unsere Bankverbindung wird Ihnen per E-Mail mitgeteilt.',
	'MODULE_PAYMENT_MONEYORDER_TEXT_EMAIL_FOOTER' => "Zahlbar an: %s\n\nAdressat:\n%s\n\nUmgehend nach Geldeingang, wird die Ware, an die von Ihnen gewünschte Adresse versandt.",
	'MODULE_PAYMENT_MONEYORDER_TEXT_INFO' => 'Zahlung im Voraus',
	'MODULE_PAYMENT_MONEYORDER_TEXT_TITLE' => 'Vorkasse (Überweisung)',
	'MODULE_PAYMENT_MONEYORDER_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_MONEYORDER_ZONE_TITLE' => 'Zahlungszone'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/moneyorder.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	moneyorder.lang.inc.php 2015-08-12
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_MONEYORDER_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_MONEYORDER_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_MONEYORDER_PAYTO_DESC' => 'An wen sollen Zahlungen erfolgen?',
	'MODULE_PAYMENT_MONEYORDER_PAYTO_ERROR' => 'Fehler: Bitte gib einen Zahlungsempfänger an.',
	'MODULE_PAYMENT_MONEYORDER_PAYTO_TITLE' => 'Zahlbar an:',
	'MODULE_PAYMENT_MONEYORDER_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_MONEYORDER_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_MONEYORDER_STATUS_DESC' => 'Möchtest du Zahlungen per Vorkasse/Überweisung akzeptieren?',
	'MODULE_PAYMENT_MONEYORDER_STATUS_TITLE' => 'Vorkasse (Überweisung) Modul aktivieren.',
	'MODULE_PAYMENT_MONEYORDER_TEXT_DESCRIPTION' => 'Unsere Bankverbindung wird Ihnen per E-Mail mitgeteilt.',
	'MODULE_PAYMENT_MONEYORDER_TEXT_EMAIL_FOOTER' => "Zahlbar an: %s\n\nAdressat:\n%s\n\nUmgehend nach Geldeingang, wird die Ware, an die von Ihnen gewünschte Adresse versandt.",
	'MODULE_PAYMENT_MONEYORDER_TEXT_INFO' => 'Zahlung im Voraus',
	'MODULE_PAYMENT_MONEYORDER_TEXT_TITLE' => 'Vorkasse (Überweisung)',
	'MODULE_PAYMENT_MONEYORDER_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_MONEYORDER_ZONE_TITLE' => 'Zahlungszone'
);
